@@ -1,8 +1,8 @@
-from quick_resto_objects.modules.front.table import Table
-from quick_resto_objects.modules.front.terminal import Terminal
-from quick_resto_objects.modules.front.shift import Shift
-from quick_resto_objects.modules.personnel.employee import Employee
-from quick_resto_objects.quick_resto_object import QuickRestoObject
+from quick_resto_API.quick_resto_objects.modules.front.table import Table
+from quick_resto_API.quick_resto_objects.modules.front.terminal import Terminal
+from quick_resto_API.quick_resto_objects.modules.front.shift import Shift
+from quick_resto_API.quick_resto_objects.modules.personnel.employee import Employee
+from quick_resto_API.quick_resto_objects.quick_resto_object import QuickRestoObject
 
 
 class OrderInfo(QuickRestoObject):
