@@ -56,8 +56,16 @@ class SingleProduct(QuickRestoObject):
     def recipe(self) -> str:
         return self._recipe
 
+    @property
+    def parent_id(self) -> int:
+        return self._parent_id
+
+    @property
+    def parent_item(self) -> dict:
+        return self._parent_item
+
     def __init__(self, version: int = None, serverRegisterTime: str = None, name: str = None, article: str = None,
-                 measureUnit: dict = None, ratio: float = None,
+                 measureUnit: dict = None, ratio: float = None, parentId:int = None, parentItem:dict = None,
                  minimalPrice: float = None, excludeDiscount: bool = None, excludeMarkup: bool = None,
                  storeQuantityKg: float = None, itemTitle: str = None,
                  basePriceInList: float = None, pack: float = None, recipe: str = None, storeItemTag: dict = None,
@@ -90,3 +98,6 @@ class SingleProduct(QuickRestoObject):
         self._base_price_in_list: float = basePriceInList
         self._pack: float = pack
         self._recipe: str = recipe
+
+        self._parent_id = parentId
+        self._parent_item = parentItem
\ No newline at end of file
